/**
 * Copyright 2024 Angus.Fenying <fenying@litert.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/// <reference types="node" />
/**
 * The base class of all HttpClient errors.
 */
export declare abstract class AbstractHttpClientError extends Error {
    context: Record<string, unknown>;
    readonly origin: unknown;
    /**
     * The unique identifier of the exception.
     */
    static id: string;
    /**
     * The description message of the exception.
     */
    static message: string;
    /**
     * The context of the exception.
     */
    static context?: Record<string, unknown>;
    constructor(context?: Record<string, unknown>, origin?: unknown);
}
export declare const E_EMPTY_AUTH_CREDENTIALS: {
    new (context?: Record<string, unknown>, origin?: unknown): {
        context: Record<string, unknown>;
        readonly origin: unknown;
        name: string;
        message: string;
        stack?: string | undefined;
    };
    id: string;
    message: string;
    /**
     * The context of the exception.
     */
    context?: Record<string, unknown> | undefined;
    captureStackTrace(targetObject: object, constructorOpt?: Function | undefined): void;
    prepareStackTrace?: ((err: Error, stackTraces: NodeJS.CallSite[]) => any) | undefined;
    stackTraceLimit: number;
};
export declare const E_UNKNOWN_AUTH_TYPE: {
    new (context?: Record<string, unknown>, origin?: unknown): {
        context: Record<string, unknown>;
        readonly origin: unknown;
        name: string;
        message: string;
        stack?: string | undefined;
    };
    id: string;
    message: string;
    /**
     * The context of the exception.
     */
    context?: Record<string, unknown> | undefined;
    captureStackTrace(targetObject: object, constructorOpt?: Function | undefined): void;
    prepareStackTrace?: ((err: Error, stackTraces: NodeJS.CallSite[]) => any) | undefined;
    stackTraceLimit: number;
};
export declare const E_NO_CONTENT_LENGTH: {
    new (context?: Record<string, unknown>, origin?: unknown): {
        context: Record<string, unknown>;
        readonly origin: unknown;
        name: string;
        message: string;
        stack?: string | undefined;
    };
    id: string;
    message: string;
    /**
     * The context of the exception.
     */
    context?: Record<string, unknown> | undefined;
    captureStackTrace(targetObject: object, constructorOpt?: Function | undefined): void;
    prepareStackTrace?: ((err: Error, stackTraces: NodeJS.CallSite[]) => any) | undefined;
    stackTraceLimit: number;
};
export declare const E_PROTOCOL_NOT_SUPPORTED: {
    new (context?: Record<string, unknown>, origin?: unknown): {
        context: Record<string, unknown>;
        readonly origin: unknown;
        name: string;
        message: string;
        stack?: string | undefined;
    };
    id: string;
    message: string;
    /**
     * The context of the exception.
     */
    context?: Record<string, unknown> | undefined;
    captureStackTrace(targetObject: object, constructorOpt?: Function | undefined): void;
    prepareStackTrace?: ((err: Error, stackTraces: NodeJS.CallSite[]) => any) | undefined;
    stackTraceLimit: number;
};
export declare const E_TOO_LARGE_RESPONSE_ENTITY: {
    new (context?: Record<string, unknown>, origin?: unknown): {
        context: Record<string, unknown>;
        readonly origin: unknown;
        name: string;
        message: string;
        stack?: string | undefined;
    };
    id: string;
    message: string;
    /**
     * The context of the exception.
     */
    context?: Record<string, unknown> | undefined;
    captureStackTrace(targetObject: object, constructorOpt?: Function | undefined): void;
    prepareStackTrace?: ((err: Error, stackTraces: NodeJS.CallSite[]) => any) | undefined;
    stackTraceLimit: number;
};
export declare const E_NO_RESPONSE_ENTITY: {
    new (context?: Record<string, unknown>, origin?: unknown): {
        context: Record<string, unknown>;
        readonly origin: unknown;
        name: string;
        message: string;
        stack?: string | undefined;
    };
    id: string;
    message: string;
    /**
     * The context of the exception.
     */
    context?: Record<string, unknown> | undefined;
    captureStackTrace(targetObject: object, constructorOpt?: Function | undefined): void;
    prepareStackTrace?: ((err: Error, stackTraces: NodeJS.CallSite[]) => any) | undefined;
    stackTraceLimit: number;
};
//# sourceMappingURL=Errors.d.ts.map