"use strict";
/**
 * Copyright 2024 Angus.Fenying <fenying@litert.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.H2SClient = void 0;
const AbstractHttp2Client_1 = require("./AbstractHttp2Client");
const $Crypto = require("crypto");
class H2SClient extends AbstractHttp2Client_1.AbstractHttp2Client {
    constructor(helper) {
        super(helper);
    }
    async request(opts, tlsSocket, key) {
        if (tlsSocket) {
            opts.connectionOptions ?? (opts.connectionOptions = {});
            opts.connectionOptions.createConnection = () => tlsSocket;
        }
        return this._processRequest(opts, key);
    }
    _prepareOptions(opts) {
        const h2Opts = {
            /**
             * Always set servername, for SNI.
             */
            'servername': opts.url.hostname,
            'minVersion': `TLSv${opts.minTLSVersion}`
        };
        if (opts.ca) {
            h2Opts.ca = opts.ca;
        }
        if (opts.localAddress) {
            h2Opts.localAddress = opts.localAddress;
        }
        return {
            ...h2Opts,
            ...opts.connectionOptions
        };
    }
    getAuthorityKey(opts) {
        if (opts.ca) {
            const hash = $Crypto.createHash('md5');
            hash.update(`${this._.getAuthority(opts.url)}/la:${opts.localAddress}/tls_v${opts.minTLSVersion}/ca:`);
            hash.end(opts.ca);
            return hash.digest('base64');
        }
        return `${this._.getAuthority(opts.url)}/la:${opts.localAddress}/tls_v${opts.minTLSVersion}`;
    }
}
exports.H2SClient = H2SClient;
//# sourceMappingURL=H2SClient.js.map